@@ -43,8 +43,11 @@ our @EXPORT = qw(
 	$MONGO_DB $MONGO_HOST $MONGO_PORT
 	$CURRENT_SEASON $CURRENT_STAGE $DATA_DIR
 	$IS_AUTHOR
+	$MERGED_FILE
 );
 
+our $MERGED_FILE = 'merged.storable';
+
 1;
 
 =head1 AUTHOR
